export let UIController = function (homeUrl, widget_data = {}) {
    const DEBUG = window.WPSHD_VCITA_DEBUG;
    const _this = this;
    this.widget_data = widget_data;
    this.HOME_URL = homeUrl;
    this.WPSHD_VCITA_URL = 'https://app.vcita.com';

    this.getRegPopupHTML = function(ud) {
        return '<div id="vcita_reg_popup">' +
            '<div class="vcita__btn__close" onclick="VcitaUI.hidePopup(true)"></div>' +
            '<img src="'+this.HOME_URL+'/images/hands-welcome.svg"/>' +
            '<div class="vcita_reg_popup-title">Welcome Onboard!</div>' +
            '<div class="vcita_reg_popup-text">' +
            '<div>Hey '+(ud.name?ud.name:ud.email)+'</div>' +
            '<div>Your account on vcita was successfully created and you are ready to accept appointments online.</div>' +
            '<div>Your default working days are <b>Monday-Friday</b> from <b>9am</b> to <b>5pm</b>. You can edit those on the settings tab.</div>' +
            '<div>Go ahead to customize your scheduling button look and feel.</div>' +
            '<div>Happy Scheduling,</div>' +
            '<div>The vcita Team</div>' +
            '</div></div>'
    };

    this.getReconnectPopupHTML = function() {
        return '<div id="vcita_reg_popup">'+
                '<div class="vcita__btn__close" onclick="VcitaUI.hidePopup(true)"></div>'+
                '<div class="vcita_reg_popup-title">Please reconnect vcita</div>'+
                '<div class="vcita_reg_popup-text">'+
                '<div>Two more steps to go:</div>'+
                '<div>1. Please reconnect your vcita account to this plugin.</div>'+
                '<div>2. RECOMMENDED: After you reconnect please schedule a demo appointment with yourself through your site to make sure that  everything works properly.</div>'+
                '<div style="text-align:center"><button class="vcita__btn__blue" onclick="event.preventDefault();event.stopPropagation();VcitaMixpman.track(\'wp_sched_login_vcita\');VcitaUI.openAuthWin(false, false)">Reconnect vcita</button></div>'+
                '</div></div>';
    };

    this.getMigratedPopupHTML = function(ud) {
        return '<div id="vcita_reg_popup">' +
            '<div class="vcita__btn__close" onclick="VcitaUI.hidePopup(true)"></div>' +
            '<img src="'+this.HOME_URL+'/images/hands-welcome.svg"/>' +
            '<div class="vcita_reg_popup-title">Fresh Scheduling Experience</div>' +
            '<div class="vcita_reg_popup-text">' +
            '<div>Hey '+(ud.name?ud.name:ud.email)+'</div>' +
            '<div>Thank you for updating the plugin.</div>' +
            '<div>What\'s new in this update? absolutely everything. To provide you a better experience we gave the plugin a fresh new design and coded everything from scratch.</div>' +
            '<div>Although the code is brand new, our team worked very hard to make sure that all vcita features you had in the previous version will remain active. In any event, we advise you to take a quick review of your site just to make sure that everything works as before.</div>' +
            '<div>If you have any issues you are welcome to contact <a href="https://support.vcita.com/hc/en-us" target="_blank">our support</a>.</div>' +
            '<div>Enjoy,</div>' +
            '<div>The vcita Team</div>' +
            '</div></div>'
    };

    this.getDeactivationPopupHTML = function(ud) {
        return '<div id="vcita_reg_popup">' +
            '<div class="vcita__btn__close" onclick="VcitaUI.hidePopup(true)"></div>' +
            '<img src="'+this.HOME_URL+'/images/hands-welcome.svg"/>' +
            '<div class="vcita_reg_popup-title">Thanks for activating vcita scheduler</div>' +
            '<div class="vcita_reg_popup-text">' +
            '<div>Hi</div>' +
            '<div>We\'ve noticed that you are using other vcita plugins</div>' +
            '<div>In order to customize your scheduling button you need to deactivate them</div>' +
            '<div><button class="vcita__btn__blue" onclick="jQuery.ajax({' +
            '\'url\':\'/wp-admin/admin-ajax.php?action=vcita_deactivate_others\',\'method\':\'GET\',' +
            '\'success\':(resp)=>{try{if(resp==\'success\'){window.location.reload()}else{VcitaUI.hidePopup()}}catch(err){console.log(err)}}})">Deactivate plugins</button></div>' +
            '<div>The vcita Team</div>' +
            '</div></div>'
    };

    this.openAlert = function(txt) {
        _this.constructPopup({userWrapper: true}, '<div class="vcita_alert_wrapper">'+txt+'</div>');
    };

    this.openAuthWin = (reg = false, logout = false) => {
        const new_location = VcitaApi.getAuthURL(reg, logout);

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita authentication',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {
                jQuery.ajax({
                    'url': '/wp-admin/admin-ajax.php?action=vcita_check_auth',
                    'method': 'POST',
                    'success': (resp) => {
                        try {
                            const ud = JSON.parse(resp);

                            if (typeof ud.uid == 'string' && ud.uid.length > 0) {
                                if (!reg) {
                                    window.location.reload();
                                    return
                                } else {
                                    VcitaMixpman.track('wp_sched_completed_registration');
                                    VcitaMixpman.track('wp_sched_welcome');
                                    window.location = '/wp-admin/admin.php?page=meeting-scheduler-by-vcita/vcita-add-to-site.php&registered=true'
                                }
                            }
                        } catch (err) { console.log(err) }
                    },
                })

                if (logout) {
                    window.location.reload()
                    return
                }
            }
        }, '<iframe src=' + new_location + '></iframe>');
    };

    this.openEditAvailabilityWin = (event) => {
        event.preventDefault();
        event.stopPropagation();
        VcitaMixpman.track('wp_sched_edit_availability');

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita edit calendar and availability',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {
                if (typeof vcita_fetch_staff == 'function') vcita_fetch_staff(true);
            }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/settings/calendar"></iframe>');
    };

    this.openEditServicesWin = (event) => {
        event.preventDefault();
        event.stopPropagation();
        VcitaMixpman.track('wp_sched_edit_services');

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita services',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {
                if (typeof vcita_fetch_staff == 'function') vcita_fetch_staff(true);
            }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/settings/services"></iframe>');
    };

    this.openEditSettingsWin = (event) => {
        event.preventDefault();
        event.stopPropagation();
        VcitaMixpman.track('wp_sched_setup');

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita settings',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {
                if (typeof vcita_fetch_staff == 'function') vcita_fetch_staff(true);
            }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/dashboard?wizard=os"></iframe>');
    };

    this.openUpgradeWin = (event) => {
        event.preventDefault();
        event.stopPropagation();

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita settings',
            width: '100%',
            height: '100%',
            iframe_onclose: () => { if (typeof vcita_sync_business == 'function') vcita_sync_business() }
        }, '<iframe ' + _this.WPSHD_VCITA_URL + '/app/settings/upgrade_page"></iframe>');
    };

    this.openSyncCalendarWin = () => {
        VcitaMixpman.track('wp_sched_sync')

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita calendar sync',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {  }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/settings/calendar"></iframe>');
    };

    this.openSyncFacebookWin = () => {
        VcitaMixpman.track('wp_sched_facebook')

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita calendar sync',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {  }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/facebook-pages"></iframe>');
    };

    this.openSyncGoogleWin = () => {
        VcitaMixpman.track('wp_sched_google')

        _this.constructPopup({
            useWrapper: true,
            title: 'vCita calendar sync',
            width: '100%',
            height: '100%',
            iframe_onclose: () => {  }
        }, '<iframe src="' + _this.WPSHD_VCITA_URL + '/app/reserve-with-google"></iframe>');
    };

    /*
    * Method used to construct popup using HTML text or DOM elements
    *
    * opts object:
    * - useWrapper [boolean] - HTML is wrapped in a container
    * - additionalClass [string] - CSS classes added to popup container element
    * - width [string] - CSS style width that is set to popup wrapper
    * - height [string] - CSS style height that is set to popup wrapper
    * - css [string] - CSS style text that is set to popup wrapper
    * - title [string] - popup title
    * - onClose [function] - function invoked when popup is closed
    * - iframe_onclose - function invoked when iframe inside popup is closed
    * */

    this.constructPopup = (opts, html) => {
        if (typeof opts != 'object' || opts == null) opts = {};
        _this.hidePopup();
        const el = document.createElement('div');
        el.id = 'vcita_popup';
        el.className = 'flex vcentered hcentered';

        if (typeof opts.additionalClass == 'string' && opts.additionalClass.trim().length > 0) {
            el.classList.add(opts.additionalClass);
        } else if (typeof opts.additionalClass == 'object' && Array.isArray(opts.additionalClass)) {
            const ll = opts.additionalClass.length;

            for (let i = 0; i < l; i++) {
                if (typeof opts.additionalClass[i] != 'string' || opts.additionalClass[i].trim().length == 0) continue;
                el.classList.add(opts.additionalClass[i]);
            }
        }

        if (typeof opts.title != 'string') opts.title = '';

        if (opts.useWrapper) {
            el.insertAdjacentHTML('beforeend', '<div><header class="flex vcentered">'
                + opts.title + '<div class="vcita__btn__close" ' +
                'onclick="event.preventDefault();event.stopPropagation();VcitaUI.hidePopup(true);"></div>'+
                '</header><div class="vc_popup_wrapper"></div></div>');
        } else el.insertAdjacentHTML('beforeend', '<div class="vc_popup_wrapper"></div>');

        document.body.appendChild(el);

        if (typeof opts.onClose == 'function') {
            el.addEventListener('popupClose', (eve) => { opts.onClose(eve) });
        }

        if (typeof opts.css == 'string') el.firstElementChild.style.cssText = opts.css;
        if (typeof opts.width == 'string') el.firstElementChild.style.width = opts.width;
        if (typeof opts.height == 'string') el.firstElementChild.style.height = opts.height;
        const c = opts.useWrapper ? el.lastElementChild.lastElementChild : el.lastElementChild;

        if (opts.useWrapper) {
            c.style.width = '100%';
            c.style.background = '#fff';
        }

        if (typeof html == 'string') {
            c.insertAdjacentHTML('beforeend', html);
        } else if (html instanceof HTMLElement) c.appendChild(html);

        let iframe = c.querySelector('iframe');

        if (iframe != null) {
            c.insertAdjacentHTML('beforeend', _this.createPreloaderHTML());

            iframe.addEventListener('load', () => {
                if (c.lastElementChild.classList.contains('vcita__preloader__container')) {
                    c.removeChild(c.lastElementChild);
                }

                let timeout = setInterval(() => {
                    if (c.querySelector('iframe') == null && typeof opts.iframe_onclose == 'function') {
                        _this.hidePopup();
                    }
                }, 10);
            });
        }

        if (typeof opts.iframe_onclose == 'function') {
            el.addEventListener('popupClose', (event) => {
                opts.iframe_onclose(event.detail);
            });
        }
    };

    this.createPreloaderHTML = () => {
        return '<mark class=\"vcita__preloader__container\">' +
            '<div class=\"lds-ring\"><div></div><div></div><div></div><div></div></div></mark>';
    };

    this.hidePopup = (ignore = false) => {
        const el = document.getElementById('vcita_popup');

        if (el != null) {
            document.body.removeChild(el);

            el.dispatchEvent(new CustomEvent('popupClose', {
                bubbles: true,
                detail: { ignore: ignore }
            }));
        }
    };
}

