<?php
/*
Plugin Name: Appointment Booking and Online Scheduling
Plugin URI: https://www.vcita.com
Description: Meeting Scheduler by vCita proves to increase the number of contact form requests
Version: 4.2
Author: vCita.com
Author URI: https://www.vcita.com
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

function vcita_enqueue_admin_scripts()
{
    wp_register_style('vcita-style', plugins_url('assets/style/style.css', __FILE__));
    wp_enqueue_style('vcita-style');
    wp_enqueue_script('jquery');
}

function wpshd_vcita_scheduler_other_plugin_installed_warning()
{
    echo "<div id='vcita-warning' class='error'><p><b>".__("vCita Plugin is already installed")."</b>".__(', please remove "<b>Appointment Booking and Online Scheduling</b>" and use the available one')."</p></div>";
}

/**
 * Check if the requested plugin is already available
 */
function wpshd_vcita_scheduler_check_plugin_available()
{
    // Check if vCita plugin already installed.
    $active_plugins = get_option('active_plugins');
    $found = array();

    foreach ($active_plugins as $filename) {
        if (strpos($filename, 'by-vcita') !== false &&
            (strpos($filename,'meeting-scheduler-by-vcita') === false ||
                strpos($filename,'meeting-scheduler-by-vcita') > 0)
        ) {
            $found[] = $filename;
        }
    }

    return $found;
}

function vcita_activate_func()
{
    $wpshd_vcita_widget = (array) get_option(WPSHD_VCITA_WIDGET_KEY);

    if (!isset($_GET['page']) || !preg_match('/'.WPSHD_VCITA_WIDGET_UNIQUE_ID.'\//',$_GET['page'])) {
        $vcita_section_url = admin_url("plugins.php?page=".plugin_basename(dirname(__FILE__))."/vcita-settings-functions.php");
        $vcita_dismiss_url = admin_url("plugins.php?page=".plugin_basename(dirname(__FILE__))."/vcita-settings-functions.php&dismiss=true");
        $prefix = "<p><b>".WPSHD_VCITA_WIDGET_PLUGIN_NAME." - </b>";
        $suffix = "</p>";
        $class = "error";

        if ((!isset($wpshd_vcita_widget["dismiss"]) || !$wpshd_vcita_widget["dismiss"])) {
            echo "<div class='".$class."'>".$prefix."You still haven't completed your Meeting Scheduler settings. <a href='".$vcita_section_url."'>Click here to learn more</a>, or <a href='".$vcita_dismiss_url."'>Dismiss.</a>".$suffix."</div>";
        }
    }

    if (!function_exists('get_plugins')) {
        require_once ABSPATH . 'wp-admin/includes/plugin.php';
    }

    $all_plugins = get_plugins();
    $class_str = '';

    foreach ($all_plugins as $wp_file => $wp_plugin) {
        if (strpos($wp_file, 'by-vcita') !== false &&
            (strpos($wp_file,'meeting-scheduler-by-vcita') === false ||
                strpos($wp_file,'meeting-scheduler-by-vcita') > 0)
        ) {
            $class_str .= ',.edit[aria-label*="' . $wp_plugin['Name'] . '"]';
        }
    }

    $prefix = '<b>'.WPSHD_VCITA_WIDGET_PLUGIN_NAME.'</b>';
    $class = "error notice is-dismissible";
    $class_str = substr($class_str, 1);

    if ($class_str) {?>
        <script type="text/javascript">
            document.addEventListener('DOMContentLoaded', function() {
                const plugs = document.querySelectorAll('<?php echo $class_str ?>');
                const pl = plugs.length;

                for (let i=0; i<pl; i++) {
                    plugs[i].onclick = function (ev) {
                        ev.preventDefault();
                        ev.stopPropagation();

                        document.querySelector('.wp-header-end').insertAdjacentHTML('afterend', '<div class="<?php echo $class ?>">' +
                            '<p>You cannot activate this plugin, because you are using <?php echo $prefix ?></p>' +
                            '<button type="button" onclick="this.parentNode.remove()" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button></div>');

                        window.scrollTo(0, 0);
                    }
                }
            });
        </script>
    <?php }
}

function vcita_admin_footer_script()
{
    global $pagenow;

    if ('plugins.php' === $pagenow) {
        wp_register_script('vcita-plugins-page-script', plugins_url('assets/js/plugins_page.js', __FILE__));
        wp_register_style('vcita-plugins-page-style', plugins_url('assets/style/plugins_page.css', __FILE__));

        wp_enqueue_script('thickbox');
        wp_enqueue_script('vcita-plugins-page-script');
        wp_enqueue_style('thickbox');
        wp_enqueue_style('vcita-plugins-page-style');

        echo '
            <div id="vcita__deactivate__modal-container" style="display:none;">
                <form id="vcita__deactivate__modal-container-inner">
                    <h3>If you have a moment, please let us know why you are deactivating:</h3>
                    <section>
                        <div><input name="reason" type="radio"><label>The plugin didn\'t work</label></div>
                        <div><input name="reason" type="radio"><label>I don\'t like to share this information with you</label></div>
                        <div><input name="reason" type="radio"><label>It\'s a temporary deactivation. I\'m just debugging an issue</label></div>
                        <div><input name="reason" type="radio"><label>I found a better plugin</label></div>
                        <div><input name="reason" type="radio"><label>Other</label></div>
                    </section>
                    <section>
                        <button onclick="vcita_send_deactivate_feedback(event,{})">Skip & deactivate</button>
                        <button onclick="vcita_send_deactivate_feedback(event,{})">We can help: Support Service</button>
                        <button onclick="vcita_send_deactivate_feedback(event,{close:true})"><b>Cancel</b></button>
                    </section>
                </form>
            </div>';
    }
}

function vcita_set_rest()
{
    register_rest_route('vcita-wordpress/v1', '/actions/(?P<action>.+)', array(
        'methods' => array('GET', 'POST'),
        'callback' => 'vcita_callback',
    ), true);
}

function vcita_update_message($data, $r)
{
    if (isset($data['upgrade_notice'])) {
        printf(
            '<div class="update-message">%s</div>',
            wpautop( $data['upgrade_notice'] )
        );
    }
}

function wpshd_vcita_check_redirect()
{
    if (get_option('wpshd_vcita_redirect_needed', false)) {
        delete_option('wpshd_vcita_redirect_needed');
        exit(wp_redirect(get_admin_url('', '', 'admin').'admin.php?page='.WPSHD_VCITA_WIDGET_UNIQUE_ID.'/vcita-settings-functions.php'));
    }
}

function wpshd_vcita_activation_func()
{
    $wpshd_vcita_widget = (array) get_option(WPSHD_VCITA_WIDGET_KEY);

    if (WPSHD_VCITA_ANOTHER_PLUGIN) {
        $av_plugin_list = wp_cache_get('WPSHD_VCITA_ANOTHER_PLUGIN_LIST');
        $wpshd_vcita_widget['deactivate_showed'] = true;

        $found = array();
        foreach ($av_plugin_list as $av_plugin) $found[] = $av_plugin['file'];
        deactivate_plugins($found);

        update_option(WPSHD_VCITA_WIDGET_KEY, $wpshd_vcita_widget);
        add_option('wpshd_vcita_redirect_needed', true);
    }
}

function wpshd_vcita_deactivation_func()
{
    $wpshd_vcita_widget = (array) get_option(WPSHD_VCITA_WIDGET_KEY);
    $wpshd_vcita_widget['deactivate_showed'] = false;
    $wpshd_vcita_widget['reconnect_showed'] = false;
    update_option(WPSHD_VCITA_WIDGET_KEY, $wpshd_vcita_widget);
}

if (WP_DEBUG && WP_DEBUG_DISPLAY && (defined('DOING_AJAX') && DOING_AJAX)) {
    @ ini_set( 'display_errors', 1 );
}

$av_plugins = wpshd_vcita_scheduler_check_plugin_available('vcita_scheduler');

if (!function_exists('get_plugins')) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

$all_plugins = get_plugins();

if ($av_plugins) {
    define('WPSHD_VCITA_ANOTHER_PLUGIN', 1);
    $all_plugin_data = array();

    foreach ($all_plugins as $wp_file => $wp_plugin) {
        if (in_array($wp_file, $av_plugins)) {
            $wp_plugin['file'] = $wp_file;

            if (strpos($wp_file, 'crm-customer-relationship-management-by-vcita') !== false ||
                strpos($wp_file, 'lead-capturing-call-to-actions-by-vcita') !== false) {
                $wp_plugin['url'] = plugin_dir_path($wp_file) . 'vcita-settings-functions.php';
                array_unshift($all_plugin_data, $wp_plugin);
            } else if (strpos($wp_file, 'paypal-payment-button-by-vcita') !== false ||
                strpos($wp_file, 'event-registration-calendar-by-vcita') !== false ||
                strpos($wp_file, 'contact-form-with-a-meeting-scheduler-by-vcita') !== false
            ) {
                $wp_plugin['url'] = 'live-site';
                $all_plugin_data[] = $wp_plugin;
            } else {
                $all_plugin_data[] = $wp_plugin;
            }
        }
    }

    wp_cache_set('WPSHD_VCITA_ANOTHER_PLUGIN_LIST', $all_plugin_data);
    foreach ($all_plugin_data as $av_plugin) $found[] = $av_plugin['file'];
    deactivate_plugins($found);
    delete_option('wpshd_vcita_redirect_needed');

    if (WPSHD_VCITA_ANOTHER_PLUGIN) {
        header('Location: ' . get_admin_url('', '', 'admin').'admin.php?page=meeting-scheduler-by-vcita/vcita-settings-functions.php');
    }
} else {
    define('WPSHD_VCITA_ANOTHER_PLUGIN', 0);
    wp_cache_set('WPSHD_VCITA_ANOTHER_PLUGIN_LIST', array());
}

define('WPSHD_VCITA_DEBUG', (isset($_GET['WPSHD_DEBUG']) && $_GET['WPSHD_DEBUG'] == 'true' ? true : false));
define('WPSHD_VCITA_API_BASE', 'https://api2.vcita.com');
define('WPSHD_VCITA_SERVER_BASE', "www.vcita.com"); /* Don't include the protocol, added dynamically */
define('WPSHD_VCITA_WIDGET_VERSION', '4.2');
define('WPSHD_VCITA_WIDGET_PLUGIN_NAME', 'Appointment Booking and Online Scheduling by vCita');
define('WPSHD_VCITA_WIDGET_KEY', 'vcita_scheduler');
define('WPSHD_VCITA_WIDGET_API_KEY', 'wp-v-schd');
define('WPSHD_VCITA_WIDGET_INVITE_CODE', 'WP-V-SCHD');
define('WPSHD_VCITA_WIDGET_MENU_NAME', 'vCita Online Scheduling');
define('WPSHD_VCITA_WIDGET_SHORTCODE', 'vCitaMeetingScheduler');
define('WPSHD_VCITA_CALENDAR_WIDGET_SHORTCODE', 'vCitaSchedulingCalendar');
define('WPSHD_VCITA_WIDGET_UNIQUE_ID', 'meeting-scheduler-by-vcita');
define('WPSHD_VCITA_WIDGET_UNIQUE_LOCATION', __FILE__);
define('WPSHD_VCITA_WIDGET_SHOW_EMAIL_PRIVACY', 'true');
// define('WPSHD_VCITA_LOGIN_PATH', WPSHD_VCITA_SERVER_BASE."/integrations/wordpress/new");
// define('WPSHD_VCITA_CHANGE_EMAIL_PATH', WPSHD_VCITA_SERVER_BASE."/integrations/wordpress/change_email");
// define('WPSHD_VCITA_SCHEDULING_PATH', WPSHD_VCITA_SERVER_BASE."/integrations/wordpress/scheduling");
// define('WPSHD_VCITA_SCHEDULING_TEST_DRIVE_PATH', WPSHD_VCITA_SERVER_BASE."/integrations/wordpress/scheduling_test_drive");
// define('WPSHD_VCITA_SCHEDULING_TEST_DRIVE_DEMO_PATH', WPSHD_VCITA_SERVER_BASE."/v/wordpress.demo/set_meeting");
define('WPSHD_VCITA_WIDGET_DEMO_UID', 'wordpress.demo'); 	/*	vCita.com/meet2know.com demo user uid: wordpress.demo */
define('WPSHD_VCITA_WIDGET_CALLBACK_URL', get_site_url() . "/wp-json/vcita-wordpress/v1/");

require_once(WP_PLUGIN_DIR."/".WPSHD_VCITA_WIDGET_UNIQUE_ID."/vcita-utility-functions.php");
require_once(WP_PLUGIN_DIR."/".WPSHD_VCITA_WIDGET_UNIQUE_ID."/vcita-widgets-functions.php");
require_once(WP_PLUGIN_DIR."/".WPSHD_VCITA_WIDGET_UNIQUE_ID."/vcita-settings-functions.php");
require_once(WP_PLUGIN_DIR."/".WPSHD_VCITA_WIDGET_UNIQUE_ID."/vcita-api-functions.php");
require_once(WP_PLUGIN_DIR."/".WPSHD_VCITA_WIDGET_UNIQUE_ID."/vcita-ajax-function.php");
/* --- Static initializer for Wordpress hooks --- */

add_action('admin_init', 'wpshd_vcita_check_redirect');
add_action('plugins_loaded', 'wpshd_vcita_init');
add_action('admin_menu', 'wpshd_vcita_admin_actions');
add_action('wp_head', 'wpshd_vcita_add_active_engage');
add_action('admin_enqueue_scripts', 'vcita_enqueue_admin_scripts');
add_action('admin_notices', 'vcita_activate_func');
add_action('admin_footer', 'vcita_admin_footer_script');

add_shortcode(WPSHD_VCITA_WIDGET_SHORTCODE, 'wpshd_vcita_add_contact');
add_shortcode(WPSHD_VCITA_CALENDAR_WIDGET_SHORTCODE, 'wpshd_vcita_add_calendar');

register_activation_hook( __FILE__, 'wpshd_vcita_activation_func');
register_deactivation_hook( __FILE__, 'wpshd_vcita_deactivation_func');

// REST Endpoint
add_action('rest_api_init', 'vcita_set_rest');

if (function_exists('register_sidebar_widget') && function_exists('register_widget_control') ){
    wp_register_sidebar_widget('vcita_widget_id', 'vcita Sidebar Widget', 'wpshd_vcita_widget_content');
    wp_register_widget_control('vcita_widget_id', 'vcita Sidebar Widget', 'wpshd_vcita_widget_admin');
}

add_filter('plugin_action_links', 'wpshd_vcita_add_settings_link', 10, 2);

global $pagenow;

if ('plugins.php' === $pagenow) {
    $file = basename(__FILE__ );
    $folder = basename(dirname( __FILE__ ));
    $hook = "in_plugin_update_message-{$folder}/{$file}";
    add_action($hook, 'vcita_update_message', 20, 2);
} ?>
